@@ -22,6 +22,7 @@
 
 
 #include "reminder.h"
+#include "../debug.h"
 
 using namespace KGAPI2;
 using namespace KCalCore;
@@ -31,7 +32,7 @@ class Q_DECL_HIDDEN Reminder::Private
   public:
     Private();
     Private(const Private &other);
-    ~Private() {};
+    ~Private() {}
 
     Alarm::Type type;
     Duration offset;
@@ -70,6 +71,20 @@ Reminder::~Reminder()
     delete d;
 }
 
+bool Reminder::operator==(const Reminder &other) const
+{
+    if (d->type != other.d->type) {
+        qCDebug(KGAPIDebug) << "Types don't match";
+        return false;
+    }
+    if (d->offset != other.d->offset) {
+        qCDebug(KGAPIDebug) << "Offsets don't match";
+        return false;
+    }
+    return true;
+}
+
+
 void Reminder::setType (Alarm::Type type)
 {
     d->type = type;
