@@ -1,5 +1,5 @@
 /*
- * This file is part of LiKGAPI library
+ * This file is part of LibKGAPI library
  *
  * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
@@ -51,7 +51,7 @@ class KGAPICORE_EXPORT FetchJob : public KGAPI2::Job
     /**
      * @brief Constructor for jobs that require authentication
      *
-     * @param account Account to use to authenticate the requests send by this job
+     * @param account Account to use to authenticate the requests sent by this job
      * @param parent
      */
     explicit FetchJob(const KGAPI2::AccountPtr &account, QObject* parent = nullptr);
@@ -59,7 +59,7 @@ class KGAPICORE_EXPORT FetchJob : public KGAPI2::Job
     /**
      * @brief Destructor
      */
-    virtual ~FetchJob();
+    ~FetchJob() override;
 
     /**
      * @brief Returns all items fetched by this job.
@@ -83,7 +83,7 @@ class KGAPICORE_EXPORT FetchJob : public KGAPI2::Job
      * @param contentType
      */
     void dispatchRequest(QNetworkAccessManager* accessManager, const QNetworkRequest& request,
-                                 const QByteArray& data, const QString& contentType) Q_DECL_OVERRIDE;
+                                 const QByteArray& data, const QString& contentType) override;
 
     /**
      * @brief KGAPI::Job::handleReply implementation
@@ -91,12 +91,12 @@ class KGAPICORE_EXPORT FetchJob : public KGAPI2::Job
      * @param rawData
      * @param contentType
      */
-    void handleReply(const QNetworkReply *reply, const QByteArray& rawData) Q_DECL_OVERRIDE;
+    void handleReply(const QNetworkReply *reply, const QByteArray& rawData) override;
 
     /**
      * @brief KGAPI::Job::aboutToStart implementation
      */
-    void aboutToStart() Q_DECL_OVERRIDE;
+    void aboutToStart() override;
 
     /**
      * @brief A reply handler that returns items parsed from \@ rawData
