@@ -34,7 +34,9 @@
 #include <QMimeType>
 #include <QMimeDatabase>
 #include <QFile>
+#include <QFileInfo>
 #include <QCryptographicHash>
+#include <QUrlQuery>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
@@ -106,7 +108,8 @@ QByteArray FileAbstractUploadJob::Private::buildMultipart(const QString &filePat
 
     // Wannabe implementation of RFC2387, i.e. multipart/related
     QByteArray body;
-    const QByteArray md5 = QCryptographicHash::hash(filePath.toLatin1(), QCryptographicHash::Md5);
+    QFileInfo finfo(filePath);
+    const QByteArray md5 = QCryptographicHash::hash(finfo.fileName().toLatin1(), QCryptographicHash::Md5);
     boundary = QString::fromLatin1(md5.toHex());
 
     body += "--" + boundary.toLatin1() + '\n';
@@ -149,16 +152,17 @@ void FileAbstractUploadJob::Private::processNext()
     }
 
     q->updateUrl(url);
-    url.addQueryItem(QStringLiteral("useContentAsIndexableText"), Utils::bool2Str(useContentAsIndexableText));
+    QUrlQuery query(url);
+    query.addQueryItem(QStringLiteral("useContentAsIndexableText"), Utils::bool2Str(useContentAsIndexableText));
 
     QNetworkRequest request;
     QByteArray rawData;
     QString contentType;
 
     // just to be sure
-    url.removeQueryItem(QStringLiteral("uploadType"));
+    query.removeQueryItem(QStringLiteral("uploadType"));
     if (metaData.isNull()) {
-        url.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("media"));
+        query.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("media"));
 
         rawData = readFile(filePath, contentType);
         if (rawData.isEmpty()) {
@@ -167,7 +171,7 @@ void FileAbstractUploadJob::Private::processNext()
         }
 
     } else if (!filePath.startsWith(QLatin1String("?="))) {
-        url.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("multipart"));
+        query.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("multipart"));
 
         QString boundary;
         rawData = buildMultipart(filePath, metaData, boundary);
@@ -181,6 +185,7 @@ void FileAbstractUploadJob::Private::processNext()
         rawData = File::toJSON(metaData, q->serializationOptions());
         contentType = QStringLiteral("application/json");
     }
+    url.setQuery(query);
 
     request.setUrl(url);
     request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
@@ -295,6 +300,11 @@ void FileAbstractUploadJob::start()
     d->processNext();
 }
 
+QMap<QString, FilePtr> FileAbstractUploadJob::files() const
+{
+    return d->uploadedFiles;
+}
+
 void FileAbstractUploadJob::dispatchRequest(QNetworkAccessManager *accessManager,
                                             const QNetworkRequest &request,
                                             const QByteArray &data,
