@@ -38,15 +38,15 @@ class KGAPIDRIVE_EXPORT RevisionFetchJob : public KGAPI2::FetchJob
 
   public:
     explicit RevisionFetchJob(const QString &fileId, const AccountPtr &account,
-                              QObject *parent = 0);
+                              QObject *parent = nullptr);
     explicit RevisionFetchJob(const QString &fileId, const QString &revisionId,
-                              const AccountPtr &account, QObject *parent = 0);
-    virtual ~RevisionFetchJob();
+                              const AccountPtr &account, QObject *parent = nullptr);
+    ~RevisionFetchJob() override;
 
   protected:
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
     KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-            const QByteArray &rawData) Q_DECL_OVERRIDE;
+            const QByteArray &rawData) override;
 
   private:
     class Private;
