@@ -117,14 +117,14 @@ class KGAPITASKS_EXPORT TaskMoveJob : public KGAPI2::ModifyJob
     /**
      * @brief Destructor
      */
-    virtual ~TaskMoveJob();
+    ~TaskMoveJob() override;
 
   protected:
 
     /**
      * @brief KGAPI2::Job::start implementation
      */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     /**
      * @brief KGAPI2::Job::dispatchRequest implementation
@@ -137,7 +137,7 @@ class KGAPITASKS_EXPORT TaskMoveJob : public KGAPI2::ModifyJob
     void dispatchRequest(QNetworkAccessManager *accessManager,
                                  const QNetworkRequest &request,
                                  const QByteArray &data,
-                                 const QString &contentType) Q_DECL_OVERRIDE;
+                                 const QString &contentType) override;
 
     /**
      * @brief KGAPI2::Job::handleReply implementation
@@ -146,7 +146,7 @@ class KGAPITASKS_EXPORT TaskMoveJob : public KGAPI2::ModifyJob
      * @param rawData
      */
     void handleReply(const QNetworkReply *reply,
-                             const QByteArray& rawData) Q_DECL_OVERRIDE;
+                             const QByteArray& rawData) override;
 
   private:
     class Private;
